# Generated by roxygen2: do not edit by hand

S3method("[",dataset_df)
S3method("[",haven_labelled_defined)
S3method("[[",haven_labelled_defined)
S3method("var_concept<-",default)
S3method("var_label<-",haven_labelled_defined)
S3method("var_namespace<-",default)
S3method("var_unit<-",default)
S3method(Ops,haven_labelled_defined)
S3method(as.Date,haven_labelled_defined)
S3method(as.POSIXct,haven_labelled_defined)
S3method(as.character,haven_labelled_defined)
S3method(as.character,prelabelled)
S3method(as.data.frame,dataset_df)
S3method(as.list,haven_labelled_defined)
S3method(as.numeric,haven_labelled_defined)
S3method(as.vector,haven_labelled_defined)
S3method(as_character,haven_labelled_defined)
S3method(as_character,prelabelled)
S3method(as_factor,haven_labelled_defined)
S3method(as_logical,haven_labelled_defined)
S3method(as_numeric,haven_labelled_defined)
S3method(as_tibble,dataset_df)
S3method(c,haven_labelled_defined)
S3method(format,haven_labelled_defined)
S3method(head,haven_labelled_defined)
S3method(is.datacite,datacite)
S3method(length,haven_labelled_defined)
S3method(names,dataset_df)
S3method(plot,dataset_df)
S3method(print,bibrecord)
S3method(print,datacite)
S3method(print,dataset_df)
S3method(print,dublincore)
S3method(print,haven_labelled_defined)
S3method(summary,dataset_df)
S3method(summary,haven_labelled_defined)
S3method(tail,haven_labelled_defined)
S3method(tbl_sum,dataset_df)
S3method(type_sum,haven_labelled_defined)
S3method(var_concept,default)
S3method(var_label,dataset_df)
S3method(var_label,defined)
S3method(var_namespace,default)
S3method(var_unit,default)
S3method(vec_cast,double.haven_labelled_defined)
S3method(xsd_convert,Date)
S3method(xsd_convert,POSIXct)
S3method(xsd_convert,character)
S3method(xsd_convert,data.frame)
S3method(xsd_convert,dataset_df)
S3method(xsd_convert,difftime)
S3method(xsd_convert,factor)
S3method(xsd_convert,haven_labelled_defined)
S3method(xsd_convert,integer)
S3method(xsd_convert,logical)
S3method(xsd_convert,numeric)
S3method(xsd_convert,tbl_df)
export("contributor<-")
export("creator<-")
export("dataset_format<-")
export("dataset_title<-")
export("description<-")
export("geolocation<-")
export("identifier<-")
export("language<-")
export("namespace_attribute<-")
export("provenance<-")
export("publication_year<-")
export("publisher<-")
export("related_item<-")
export("relation<-")
export("rights<-")
export("set_bibentry<-")
export("subject<-")
export("unit_attribute<-")
export("var_concept<-")
export("var_label<-")
export("var_labels<-")
export("var_namespace<-")
export("var_unit<-")
export(as.tibble.dataset_df)
export(as_character)
export(as_datacite)
export(as_dataset_df)
export(as_dublincore)
export(as_factor)
export(as_logical)
export(as_numeric)
export(as_tibble)
export(as_value_key)
export(bibrecord)
export(bind_defined_rows)
export(contributor)
export(creator)
export(datacite)
export(dataset_df)
export(dataset_format)
export(dataset_title)
export(dataset_to_triples)
export(defined)
export(describe)
export(description)
export(dublincore)
export(geolocation)
export(get_bibentry)
export(get_namespace_attribute)
export(get_unit_attribute)
export(get_variable_concepts)
export(get_variable_namespaces)
export(get_variable_units)
export(id_to_column)
export(identifier)
export(invert_value_key)
export(is.dataset_df)
export(is.defined)
export(is.dublincore)
export(is.prelabelled)
export(is.related)
export(is_dataset_df)
export(label_attribute)
export(language)
export(n_triple)
export(n_triples)
export(namespace_attribute)
export(prelabel)
export(provenance)
export(publication_year)
export(publisher)
export(related_create)
export(related_item)
export(relation)
export(rights)
export(set_namespace_attribute)
export(set_unit_attribute)
export(strip_defined)
export(subject)
export(subject_create)
export(unit_attribute)
export(var_concept)
export(var_label)
export(var_labels)
export(var_namespace)
export(var_unit)
export(xsd_convert)
importFrom(assertthat,assert_that)
importFrom(haven,as_factor)
importFrom(haven,labelled)
importFrom(labelled,`var_label<-`)
importFrom(labelled,is.labelled)
importFrom(labelled,label_attribute)
importFrom(labelled,var_label)
importFrom(pillar,tbl_sum)
importFrom(pillar,type_sum)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(tibble,new_tibble)
importFrom(tibble,tibble)
importFrom(utils,bibentry)
importFrom(utils,citation)
importFrom(utils,head)
importFrom(utils,person)
importFrom(utils,tail)
importFrom(vctrs,vec_cast)
importFrom(vctrs,vec_data)
