---
title: "Example Dataset Definitions"
output:
  rmarkdown::html_vignette:
    md_extensions: -autolink_bare_uris
vignette: >
  %\VignetteIndexEntry{Example Dataset Definitions}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

<!-- Machine-readable alternate -->
<link rel="alternate" type="text/turtle" href="https://dataset.dataobservatory.eu/examples/dataset.ttl" />

This page documents the illustrative IRIs used in the `dataset` package
vignettes. They are **examples only** and do not point to real datasets. 

## Purpose

- To illustrate how IRIs can uniquely identify dataset elements.  
- To provide dereferenceable links that pass CRAN checks.  
- To show Linked Data best practice: one namespace doc, with fragments. 

# Example Dataset Definitions For RDF

The base namespace in `vignette("rdf", package = "dataset")` is:

<https://dataset.dataobservatory.eu/examples/dataset.html#>

Although these example IRIs use `.html#` in the base namespace, the `.html` part
does not imply that the resource is literally an HTML file. In RDF, any absolute
IRI is valid. We use this form only for illustration, because the R package
documentation infrastructure is not designed to support full content
negotiation between human-readable HTML and machine-readable Turtle files.  
In real publishing scenarios, a bare namespace ending with `/dataset#` is more
conventional.

---

<a id="obs:1"></a>

## obs:1

Example observation 1 (not real data).  


<a id="obs:2"></a>

## obs:2  

Example observation 2 (not real data).  

<a id="obs:3"></a>

## obs:3  
Example observation 3 (not real data).  

---

In real publishing scenarios, you would replace these with persistent URIs
that identify actual datasets and their observations. For example, a DOI-based identifier such as:

`https://doi.org/10.5281/zenodo.14917851#obs:1`

could be used to refer to the first observation in a dataset archived at Zenodo. 

## Machine-readable form

A Turtle serialization of the same example definitions is also available: 


```
@prefix ex:   <https://dataset.dataobservatory.eu/examples/dataset#> .
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix dcat: <http://www.w3.org/ns/dcat#> .

ex:obs1 a dcat:Observation ;
    rdfs:label "Example observation 1 (not real data)" .

ex:obs2 a dcat:Observation ;
    rdfs:label "Example observation 2 (not real data)" .

ex:obs3 a dcat:Observation ;
    rdfs:label "Example observation 3 (not real data)" .
```

In fact, semantic applications know that they should not even read this HTML page, but instead go directly to the `dataset.ttl` version, as it is a World Wide Web standard to disseminate data and metadata.

👉 [Download dataset.ttl](https://dataset.dataobservatory.eu/examples/dataset.ttl)  
