% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/defined.R
\name{vec_cast_named}
\alias{vec_cast_named}
\title{From haven}
\usage{
vec_cast_named(x, to, ...)
}
\description{
From haven
}
\keyword{internal}
